# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKCommonPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkNeighborhoodPython
else:
    import _itkNeighborhoodPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkRGBPixelPython
import itk.itkSizePython
import itk.itkCovariantVectorPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkOffsetPython
class itkNeighborhoodB2(object):
    r"""Proxy of C++ itkNeighborhoodB2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodB2_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodB2

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodB2
        __init__(self, arg0) -> itkNeighborhoodB2

        Parameters
        ----------
        arg0: itkNeighborhoodB2 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodB2_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodB2(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodB2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodB2___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodB2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodB2___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize2
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodB2_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize2
        """
        return _itkNeighborhoodPython.itkNeighborhoodB2_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodB2_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodB2_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> bool &

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodB2_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> bool"""
        return _itkNeighborhoodPython.itkNeighborhoodB2_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize2 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodB2_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodB2_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< bool >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< bool > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodB2_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset2

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodB2_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodB2_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodB2_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodB2_GetSlice(self, arg0)

# Register itkNeighborhoodB2 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodB2_swigregister(itkNeighborhoodB2)
class itkNeighborhoodB3(object):
    r"""Proxy of C++ itkNeighborhoodB3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodB3_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodB3

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodB3
        __init__(self, arg0) -> itkNeighborhoodB3

        Parameters
        ----------
        arg0: itkNeighborhoodB3 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodB3_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodB3(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodB3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodB3___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodB3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodB3___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize3
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodB3_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize3
        """
        return _itkNeighborhoodPython.itkNeighborhoodB3_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodB3_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodB3_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> bool &

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodB3_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> bool"""
        return _itkNeighborhoodPython.itkNeighborhoodB3_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize3 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodB3_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodB3_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< bool >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< bool > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodB3_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset3

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodB3_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodB3_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodB3_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodB3_GetSlice(self, arg0)

# Register itkNeighborhoodB3 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodB3_swigregister(itkNeighborhoodB3)
class itkNeighborhoodCVF22(object):
    r"""Proxy of C++ itkNeighborhoodCVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodCVF22

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodCVF22
        __init__(self, arg0) -> itkNeighborhoodCVF22

        Parameters
        ----------
        arg0: itkNeighborhoodCVF22 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodCVF22_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodCVF22(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodCVF22 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodCVF22 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize2
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize2
        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> itkCovariantVectorF2

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> itkCovariantVectorF2"""
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize2 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::CovariantVector< float,2 > >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::CovariantVector< float,2 > > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset2

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF22_GetSlice(self, arg0)

# Register itkNeighborhoodCVF22 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodCVF22_swigregister(itkNeighborhoodCVF22)
class itkNeighborhoodCVF33(object):
    r"""Proxy of C++ itkNeighborhoodCVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodCVF33

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodCVF33
        __init__(self, arg0) -> itkNeighborhoodCVF33

        Parameters
        ----------
        arg0: itkNeighborhoodCVF33 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodCVF33_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodCVF33(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodCVF33 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodCVF33 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize3
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize3
        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> itkCovariantVectorF3

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> itkCovariantVectorF3"""
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize3 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::CovariantVector< float > >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::CovariantVector< float > > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset3

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodCVF33_GetSlice(self, arg0)

# Register itkNeighborhoodCVF33 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodCVF33_swigregister(itkNeighborhoodCVF33)
class itkNeighborhoodF2(object):
    r"""Proxy of C++ itkNeighborhoodF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodF2_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodF2

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodF2
        __init__(self, arg0) -> itkNeighborhoodF2

        Parameters
        ----------
        arg0: itkNeighborhoodF2 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodF2_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodF2(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodF2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodF2___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodF2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodF2___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize2
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodF2_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize2
        """
        return _itkNeighborhoodPython.itkNeighborhoodF2_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodF2_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodF2_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> float &

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodF2_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> float"""
        return _itkNeighborhoodPython.itkNeighborhoodF2_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize2 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodF2_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodF2_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< float >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< float > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodF2_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset2

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodF2_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodF2_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodF2_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodF2_GetSlice(self, arg0)

# Register itkNeighborhoodF2 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodF2_swigregister(itkNeighborhoodF2)
class itkNeighborhoodF3(object):
    r"""Proxy of C++ itkNeighborhoodF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodF3_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodF3

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodF3
        __init__(self, arg0) -> itkNeighborhoodF3

        Parameters
        ----------
        arg0: itkNeighborhoodF3 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodF3_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodF3(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodF3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodF3___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodF3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodF3___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize3
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodF3_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize3
        """
        return _itkNeighborhoodPython.itkNeighborhoodF3_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodF3_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodF3_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> float &

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodF3_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> float"""
        return _itkNeighborhoodPython.itkNeighborhoodF3_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize3 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodF3_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodF3_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< float >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< float > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodF3_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset3

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodF3_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodF3_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodF3_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodF3_GetSlice(self, arg0)

# Register itkNeighborhoodF3 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodF3_swigregister(itkNeighborhoodF3)
class itkNeighborhoodRGBUC2(object):
    r"""Proxy of C++ itkNeighborhoodRGBUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodRGBUC2

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodRGBUC2
        __init__(self, arg0) -> itkNeighborhoodRGBUC2

        Parameters
        ----------
        arg0: itkNeighborhoodRGBUC2 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodRGBUC2_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodRGBUC2(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodRGBUC2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodRGBUC2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize2
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize2
        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> itkRGBPixelUC

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> itkRGBPixelUC"""
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize2 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::RGBPixel< unsigned char > >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::RGBPixel< unsigned char > > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset2

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC2_GetSlice(self, arg0)

# Register itkNeighborhoodRGBUC2 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodRGBUC2_swigregister(itkNeighborhoodRGBUC2)
class itkNeighborhoodRGBUC3(object):
    r"""Proxy of C++ itkNeighborhoodRGBUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodRGBUC3

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodRGBUC3
        __init__(self, arg0) -> itkNeighborhoodRGBUC3

        Parameters
        ----------
        arg0: itkNeighborhoodRGBUC3 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodRGBUC3_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodRGBUC3(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodRGBUC3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodRGBUC3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize3
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize3
        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> itkRGBPixelUC

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> itkRGBPixelUC"""
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize3 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::RGBPixel< unsigned char > >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::RGBPixel< unsigned char > > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset3

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodRGBUC3_GetSlice(self, arg0)

# Register itkNeighborhoodRGBUC3 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodRGBUC3_swigregister(itkNeighborhoodRGBUC3)
class itkNeighborhoodSS2(object):
    r"""Proxy of C++ itkNeighborhoodSS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodSS2_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodSS2

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodSS2
        __init__(self, arg0) -> itkNeighborhoodSS2

        Parameters
        ----------
        arg0: itkNeighborhoodSS2 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodSS2_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodSS2(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodSS2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodSS2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize2
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize2
        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodSS2_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> short &

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> short"""
        return _itkNeighborhoodPython.itkNeighborhoodSS2_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize2 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< short >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< short > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset2

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodSS2_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS2_GetSlice(self, arg0)

# Register itkNeighborhoodSS2 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodSS2_swigregister(itkNeighborhoodSS2)
class itkNeighborhoodSS3(object):
    r"""Proxy of C++ itkNeighborhoodSS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodSS3_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodSS3

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodSS3
        __init__(self, arg0) -> itkNeighborhoodSS3

        Parameters
        ----------
        arg0: itkNeighborhoodSS3 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodSS3_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodSS3(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodSS3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodSS3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize3
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize3
        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodSS3_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> short &

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> short"""
        return _itkNeighborhoodPython.itkNeighborhoodSS3_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize3 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< short >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< short > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset3

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodSS3_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodSS3_GetSlice(self, arg0)

# Register itkNeighborhoodSS3 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodSS3_swigregister(itkNeighborhoodSS3)
class itkNeighborhoodUC2(object):
    r"""Proxy of C++ itkNeighborhoodUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodUC2_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodUC2

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodUC2
        __init__(self, arg0) -> itkNeighborhoodUC2

        Parameters
        ----------
        arg0: itkNeighborhoodUC2 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodUC2_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodUC2(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodUC2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodUC2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize2
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize2
        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodUC2_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> unsigned char &

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> unsigned char"""
        return _itkNeighborhoodPython.itkNeighborhoodUC2_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize2 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< unsigned char >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< unsigned char > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset2

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodUC2_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC2_GetSlice(self, arg0)

# Register itkNeighborhoodUC2 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodUC2_swigregister(itkNeighborhoodUC2)
class itkNeighborhoodUC3(object):
    r"""Proxy of C++ itkNeighborhoodUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodUC3_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodUC3

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodUC3
        __init__(self, arg0) -> itkNeighborhoodUC3

        Parameters
        ----------
        arg0: itkNeighborhoodUC3 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodUC3_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodUC3(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodUC3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodUC3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize3
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize3
        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodUC3_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> unsigned char &

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> unsigned char"""
        return _itkNeighborhoodPython.itkNeighborhoodUC3_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize3 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< unsigned char >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< unsigned char > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset3

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodUC3_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodUC3_GetSlice(self, arg0)

# Register itkNeighborhoodUC3 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodUC3_swigregister(itkNeighborhoodUC3)
class itkNeighborhoodVF22(object):
    r"""Proxy of C++ itkNeighborhoodVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodVF22_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodVF22

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodVF22
        __init__(self, arg0) -> itkNeighborhoodVF22

        Parameters
        ----------
        arg0: itkNeighborhoodVF22 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodVF22_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodVF22(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodVF22 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodVF22 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize2
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize2
        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodVF22_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> itkVectorF2

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> itkVectorF2"""
        return _itkNeighborhoodPython.itkNeighborhoodVF22_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize2 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::Vector< float,2 > >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::Vector< float,2 > > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset2

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset2 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodVF22_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF22_GetSlice(self, arg0)

# Register itkNeighborhoodVF22 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodVF22_swigregister(itkNeighborhoodVF22)
class itkNeighborhoodVF33(object):
    r"""Proxy of C++ itkNeighborhoodVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNameOfClass(self):
        r"""GetNameOfClass(self) -> char const *"""
        return _itkNeighborhoodPython.itkNeighborhoodVF33_GetNameOfClass(self)
    __swig_destroy__ = _itkNeighborhoodPython.delete_itkNeighborhoodVF33

    def __init__(self, *args):
        r"""
        __init__(self) -> itkNeighborhoodVF33
        __init__(self, arg0) -> itkNeighborhoodVF33

        Parameters
        ----------
        arg0: itkNeighborhoodVF33 const &

        """
        _itkNeighborhoodPython.itkNeighborhoodVF33_swiginit(self, _itkNeighborhoodPython.new_itkNeighborhoodVF33(*args))

    def __eq__(self, other):
        r"""
        __eq__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodVF33 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33___eq__(self, other)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkNeighborhoodVF33 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33___ne__(self, other)

    def GetRadius(self, *args):
        r"""
        GetRadius(self) -> itkSize3
        GetRadius(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33_GetRadius(self, *args)

    def GetSize(self, *args):
        r"""
        GetSize(self, n) -> unsigned long

        Parameters
        ----------
        n: unsigned int

        GetSize(self) -> itkSize3
        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33_GetSize(self, *args)

    def GetStride(self, axis):
        r"""
        GetStride(self, axis) -> long

        Parameters
        ----------
        axis: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33_GetStride(self, axis)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodVF33_Size(self)

    def GetElement(self, i):
        r"""
        GetElement(self, i) -> itkVectorF3

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33_GetElement(self, i)

    def GetCenterValue(self):
        r"""GetCenterValue(self) -> itkVectorF3"""
        return _itkNeighborhoodPython.itkNeighborhoodVF33_GetCenterValue(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: itkSize3 const &

        SetRadius(self, rad)

        Parameters
        ----------
        rad: unsigned long const *

        SetRadius(self, arg0)

        Parameters
        ----------
        arg0: unsigned long const

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33_SetRadius(self, *args)

    def Print(self, os):
        r"""
        Print(self, os)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33_Print(self, os)

    def GetBufferReference(self, *args):
        r"""
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::Vector< float > >
        GetBufferReference(self) -> itk::NeighborhoodAllocator< itk::Vector< float > > const &
        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33_GetBufferReference(self, *args)

    def GetOffset(self, i):
        r"""
        GetOffset(self, i) -> itkOffset3

        Parameters
        ----------
        i: unsigned long

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33_GetOffset(self, i)

    def GetNeighborhoodIndex(self, arg0):
        r"""
        GetNeighborhoodIndex(self, arg0) -> unsigned long

        Parameters
        ----------
        arg0: itkOffset3 const &

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33_GetNeighborhoodIndex(self, arg0)

    def GetCenterNeighborhoodIndex(self):
        r"""GetCenterNeighborhoodIndex(self) -> unsigned long"""
        return _itkNeighborhoodPython.itkNeighborhoodVF33_GetCenterNeighborhoodIndex(self)

    def GetSlice(self, arg0):
        r"""
        GetSlice(self, arg0) -> std::slice

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkNeighborhoodPython.itkNeighborhoodVF33_GetSlice(self, arg0)

# Register itkNeighborhoodVF33 in _itkNeighborhoodPython:
_itkNeighborhoodPython.itkNeighborhoodVF33_swigregister(itkNeighborhoodVF33)

